@@ -27,12 +27,8 @@
 #include "kmime_content.h"
 #include "kmime_headers.h"
 
-#include <QtCore/QMetaType>
-
-namespace boost
-{
-template <typename T> class shared_ptr;
-}
+#include <QMetaType>
+#include <QSharedPointer>
 
 namespace KMime
 {
@@ -50,7 +46,9 @@ class MessagePrivate;
  * ct->setMimeType( "multipart/mixed" );
  * ct->setBoundary( multiPartBoundary() );
  * ct->setCategory( Headers::CCcontainer );
- * m->contentTransferEncoding()->clear();
+ * Headers::ContentTransferEncoding *cte = m->contentTransferEncoding();
+ * cte->setEncoding(Headers::CE7Bit);
+ * cte->setDecoded(true);
  *
  * // Set the headers.
  * m->from()->fromUnicodeString( "some@mailaddy.com", "utf-8" );
@@ -82,15 +80,10 @@ class MessagePrivate;
 class KMIME_EXPORT Message : public Content
 {
 public:
-    /**
-      A list of messages.
-    */
-    typedef QList<KMime::Message *> List;
-
     /**
       A shared pointer to a message object.
     */
-    typedef boost::shared_ptr<Message> Ptr;
+    typedef QSharedPointer<Message> Ptr;
 
     /**
       Creates an empty Message.
@@ -102,87 +95,83 @@ public:
     */
     ~Message();
 
-    // KDE5: Why are these virtual?
     /**
       Returns the Message-ID header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::MessageID *messageID(bool create = true);
+    KMime::Headers::MessageID *messageID(bool create = true);
 
     /**
       Returns the Subject header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::Subject *subject(bool create = true);
+    KMime::Headers::Subject *subject(bool create = true);
 
     /**
       Returns the Date header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::Date *date(bool create = true);
+    KMime::Headers::Date *date(bool create = true);
 
     /**
       Returns the From header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::From *from(bool create = true);
+    KMime::Headers::From *from(bool create = true);
 
     /**
       Returns the Organization header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::Organization *organization(bool create = true);
+    KMime::Headers::Organization *organization(bool create = true);
 
     /**
       Returns the Reply-To header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::ReplyTo *replyTo(bool create = true);
+    KMime::Headers::ReplyTo *replyTo(bool create = true);
 
     /**
       Returns the To header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::To *to(bool create = true);
+    KMime::Headers::To *to(bool create = true);
 
     /**
       Returns the Cc header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::Cc *cc(bool create = true);
+    KMime::Headers::Cc *cc(bool create = true);
 
     /**
       Returns the Bcc header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::Bcc *bcc(bool create = true);
+    KMime::Headers::Bcc *bcc(bool create = true);
 
     /**
       Returns the References header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::References *references(bool create = true);
+    KMime::Headers::References *references(bool create = true);
 
     /**
       Returns the User-Agent header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::UserAgent *userAgent(bool create = true);
+    KMime::Headers::UserAgent *userAgent(bool create = true);
 
     /**
       Returns the In-Reply-To header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::InReplyTo *inReplyTo(bool create = true);
+    KMime::Headers::InReplyTo *inReplyTo(bool create = true);
 
     /**
       Returns the Sender header.
       @param create If true, create the header if it doesn't exist yet.
     */
-    virtual KMime::Headers::Sender *sender(bool create = true);
-
-    /* reimpl */
-    virtual bool isTopLevel() const;
+    KMime::Headers::Sender *sender(bool create = true);
 
     /**
       Returns the first main body part of a given type, taking multipart/mixed
@@ -201,12 +190,7 @@ public:
     static QString mimeType();
 
 protected:
-    /* reimpl */
-    virtual QByteArray assembleHeaders();
-
-    // @cond PRIVATE
-    explicit Message(MessagePrivate *d);
-    // @endcond
+    QByteArray assembleHeaders() override;
 
 private:
     Q_DECLARE_PRIVATE(Message)
@@ -215,7 +199,7 @@ private:
 
 } // namespace KMime
 
-#define KMIME_MESSAGE_METATYPE_DEFINED 1
-Q_DECLARE_METATYPE(KMime::Message *)
+Q_DECLARE_METATYPE(KMime::Message*)
+Q_DECLARE_METATYPE(KMime::Message::Ptr)
 
 #endif // __KMIME_MESSAGE_H__
